<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>JUST NOW</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 הודעה חדשה</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 דקות קודם לכן</translation>
    </message>
</context>
</TS>